summaryrefslogtreecommitdiff
path: root/thread.h
diff options
context:
space:
mode:
authorMalcolm Beattie <mbeattie@sable.ox.ac.uk>1997-11-06 14:31:38 +0000
committerMalcolm Beattie <mbeattie@sable.ox.ac.uk>1997-11-06 14:31:38 +0000
commit199100c871a030cc44240072644abe9aab66bc02 (patch)
treeb88def55f8e42b978120f498a2e4197260d5db23 /thread.h
parent554b3ecafd2a8f619792c82298bc621b9e48a923 (diff)
downloadperl-199100c871a030cc44240072644abe9aab66bc02.tar.gz
Per-thread magicals now stored in their own thr->magicals and keyed
more directly. cvcache and oursv become ordinary struct thread fields instead of #defined thr->Tfoo ones. SvREFCNT_inc now checks for 0 again. Main thread initialisation done by new function init_main_thread instead of (now fixed) new_struct_thread. p4raw-id: //depot/perl@205
Diffstat (limited to 'thread.h')
-rw-r--r--thread.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/thread.h b/thread.h
index f7668c1173..b496d6997c 100644
--- a/thread.h
+++ b/thread.h
@@ -213,8 +213,8 @@ struct thread {
/* XXX Sort stuff, firstgv, secongv and so on? */
- SV * Toursv;
- HV * Tcvcache;
+ SV * oursv;
+ HV * cvcache;
perl_thread self; /* Underlying thread object */
U32 flags;
AV * magicals; /* Per-thread magicals */
@@ -226,7 +226,7 @@ struct thread {
#ifdef ADD_THREAD_INTERN
struct thread_intern i; /* Platform-dependent internals */
#endif
- char trailing_nul; /* For the sake of thrsv, t->Toursv */
+ char trailing_nul; /* For the sake of thrsv and oursv */
};
typedef struct thread *Thread;
@@ -314,7 +314,6 @@ typedef struct condpair {
#undef dirty
#undef localizing
-#define oursv (thr->Toursv)
#define stack_base (thr->Tstack_base)
#define stack_sp (thr->Tstack_sp)
#define stack_max (thr->Tstack_max)
@@ -381,7 +380,6 @@ typedef struct condpair {
#define top_env (thr->Ttop_env)
#define runlevel (thr->Trunlevel)
-#define cvcache (thr->Tcvcache)
#else
/* USE_THREADS is not defined */
#define MUTEX_LOCK(m)